@@ -2,7 +2,7 @@
 import os
 import shutil
 from pkg_resources import resource_filename
-from __init__ import Logya
+from logya.core import Logya
 
 
 class Create(Logya):
@@ -13,4 +13,4 @@ class Create(Logya):
         super(self.__class__, self).__init__()
         src = resource_filename(__name__, 'sites/docs')
         dst = os.path.join(self.dir_current, name)
-        shutil.copytree(src, dst)
+        shutil.copytree(src, dst)
\ No newline at end of file
