@@ -2,7 +2,10 @@
 import os
 import yaml
 import markdown
+
 from datetime import datetime
+from logya.compat import file_open as open
+
 
 class DocParser():
     """Class for parsing content documents."""
@@ -11,7 +14,7 @@ class DocParser():
         """Parse document and return a dictionary of header fields and body."""
 
         stat = os.stat(filename)
-        f = open(filename, 'r')
+        f = open(filename, 'r', encoding='utf-8')
         content = f.read()
         f.close()
 
@@ -19,7 +22,7 @@ class DocParser():
         pos1 = content.index('---')
         pos2 = content.index('---', pos1 + 1)
         header = content[pos1:pos2].strip()
-        body = content[pos2+3:].strip()
+        body = content[pos2 + 3:].strip()
 
         # parse body if not HTML/XML
         fext = os.path.splitext(filename)[1]
