@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
 import os
+from logya.globals import allowed_exts
 
 
 class DocReader:
@@ -12,8 +13,10 @@ class DocReader:
         self.parser = parser
         self.files = []
         for root, dirs, files in os.walk(self.dir_base):
-            self.files.extend([os.path.join(root, f) for f in files])
-
+            self.files.extend([
+                os.path.join(root, f) for f in files
+                    if os.path.splitext(f)[1].strip('.') in allowed_exts
+            ])
 
     def get_docs(self):
         """Generator that reads all docs from base directory."""
